
``ext`` module
========================================

.. automodule:: docit.ext
    :members:
    :special-members:
    :undoc-members:
    :show-inheritance:
    :synopsis: The actual sphinx extension
